@@ -2,8 +2,8 @@
 # -*- encoding: utf-8 -*-
 # @Author: https://github.com/Evil0ctal/
 # @Time: 2021/11/06
-# @Update: 2022/12/09
-# @Version: 3.1.5
+# @Update: 2022/12/19
+# @Version: 3.1.7
 # @Function:
 # 核心代码，估值1块(๑•̀ㅂ•́)و✧
 # 用于爬取Douyin/TikTok数据并以字典形式返回。
@@ -12,7 +12,6 @@
 
 import re
 import os
-import random
 import aiohttp
 import platform
 import asyncio
@@ -286,9 +285,7 @@ class Scraper:
             # 转换链接/Convert link
             original_url = await self.convert_share_urls(original_url)
             # 获取视频ID/Get video ID
-            if '.html' in original_url:
-                video_id = original_url.replace('.html', '')
-            elif '/video/' in original_url:
+            if '/video/' in original_url:
                 video_id = re.findall('/video/(\d+)', original_url)[0]
             elif '/v/' in original_url:
                 video_id = re.findall('/v/(\d+)', original_url)[0]
@@ -309,7 +306,7 @@ class Scraper:
         print('正在获取TikTok视频数据...')
         try:
             # 构造访问链接/Construct the access link
-            api_url = f'https://api16-normal-c-useast1a.tiktokv.com/aweme/v1/feed/?aweme_id={video_id}&iid=6165993682518218889&device_id={random.randint(10*10*10, 9*10**10)}&aid=1180'
+            api_url = f'https://api16-normal-c-useast1a.tiktokv.com/aweme/v1/feed/?aweme_id={video_id}&aid=1180'
             print("正在获取视频数据API: {}".format(api_url))
             async with aiohttp.ClientSession() as session:
                 async with session.get(api_url, headers=self.tiktok_api_headers, proxy=self.proxies, timeout=10) as response:
@@ -390,7 +387,7 @@ class Scraper:
                         else
                         {
                             "User-Agent": self.tiktok_api_headers["User-Agent"],
-                            "api_url": f'https://api16-normal-c-useast1a.tiktokv.com/aweme/v1/feed/?aweme_id={video_id}&iid=6165993682518218889&device_id={random.randint(10*10*10, 9*10**10)}&aid=1180'
+                            "api_url": f'https://api16-normal-c-useast1a.tiktokv.com/aweme/v1/feed/?aweme_id={video_id}&aid=1180'
                         },
                     'desc': data.get("desc"),
                     'create_time': data.get("create_time"),
